<?php

/**
 * @package         EngageBox
 * @version         4.2.2 Pro
 * 
 * @author          Tassos Marinos <info@tassos.gr>
 * @link            http://www.tassos.gr
 * @copyright       Copyright © 2020 Tassos Marinos All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
*/

namespace EngageBox;

defined('_JEXEC') or die('Restricted access');

use NRFramework\Cache;
use Joomla\Registry\Registry;

class Box
{
    public static function render($box)
    {
        \JPluginHelper::importPlugin('engagebox');

        // Check Publishing Assignments
        if (!self::pass($box))
        {
            return;
        }

        \JFactory::getApplication()->triggerEvent('onEngageBoxBeforeRender', [&$box]);

        self::prepare($box);

        $layout = new \JLayoutFile('box', null, ['debug' => false, 'client' => 1, 'component' => 'com_rstbox']);
        $html = $layout->render($box);

        \JFactory::getApplication()->triggerEvent('onEngageBoxAfterRender', [&$html, $box]);

        // Load the expression script only if an expression shortcode is found in the content
        if (strpos($html, '{ebExpr') !== false)
        {
            \JHtml::script('com_rstbox/expression.js', ['relative' => true, 'version' => 'auto']);
        }

        return $html;
    }

    private static function prepare(&$box)
    {
        $cParam = Helper::getParams();

        $css_class_prefix = 'eb-';

        $box->content = \JFactory::getApplication()->triggerEvent('onEngageBoxTypeRender', array($box));
        $box->content = implode(' ', $box->content);

        /* Classes */
        $css_class = [
            $box->id,
            $box->position,
            $box->boxtype
        ];

        $rtl = $box->params->get('rtl', '2') == '2' ? $cParam->get('rtl', false) : $box->params->get('rtl');
        $box->rtl = $rtl;
        if ($rtl)
        {
            $css_class[] = 'rtl';
        }

        self::prefixCSSClasses($css_class);

        $css_class[] = $box->params->get('classsuffix', '');

        $box->classes = $css_class;

        $dialog_css_classes = [
            $box->params->get('boxshadow', 'none') != 'none' ? 'shd' . $box->params->get('boxshadow', '1') : null,
            $box->boxtype == 'emailform' ? 'form' . ucfirst($box->params->get('formorient', 'ver')) : null
        ];

        // Align Content
        $dialog_css_classes = array_merge($dialog_css_classes, explode(' ', $box->params->get('aligncontent')));

        self::prefixCSSClasses($dialog_css_classes);
        $box->dialog_classes = $dialog_css_classes;

        /* CSS */
        $margin  = $box->params->get('margin', '');
        $border  = $box->params->get('bordertype', 'none');
        $padd    = $box->params->get('padding');

        $style = [
            'max-width'        => $box->params->get('width'),
            'height'           => $box->params->get('height') == 'auto' ? null : $box->params->get('height'),
            'background-color' => $box->params->get('backgroundcolor'),
            'color'            => $box->params->get('textcolor'),
            'border'           => $border == 'none' ? null : $border . ' ' . $box->params->get('borderwidth', 0) . ' ' . $box->params->get('bordercolor'),
            'border-radius'    => $box->params->get('borderradius'),
            'padding'          => $padd == '30px' ? null : $padd,
            'margin'           => !empty($margin) && !in_array($margin, ['0px', 'auto']) ? $margin : null
        ];

        // Background Image
        if ($box->params->get('bgimage', false))
        {
            $style['background-image']  = 'url(\'' . \JURI::root() . $box->params->get('bgimagefile') . '\')';
            $style['background-repeat'] = strtolower($box->params->get('bgrepeat'));
            $style['background-size'] = strtolower($box->params->get("bgsize"));
            $style['background-position'] = strtolower($box->params->get("bgposition"));
        }

        $box->style = Helper::arrayToCSSS($style);

        $trigger_point_methods = [
            'pageheight'   => 'onScrollDepth',
            'element'      => 'onElementVisibility',
            'pageready'    => 'onPageReady',
            'pageload'     => 'onPageLoad',
            'userleave'    => 'onExit',
            'onclick'      => 'onClick',
            'elementHover' => 'onHover',
            'ondemand'     => 'onDemand'
        ];

        /* Other Settings */
        // Use Namespaced classes for each trigger point and let them manipulate the settings dynamicaly.
        $box->settings = [
            'trigger'              => array_key_exists($box->triggermethod, $trigger_point_methods) ? $trigger_point_methods[$box->triggermethod] : $box->triggermethod,
            'trigger_selector'     => $box->params->get('triggerelement'),
            'delay'                => (int) $box->params->get('triggerdelay'),
            //'scroll_dir'           => $box->params->get('scroll_dir', 'down'),
            'scroll_depth'         => $box->params->get('scroll_depth', 'percentage'),
            'scroll_depth_value'   => $box->params->get('scroll_depth', 'percentage') == 'percentage' ? (int) $box->params->get('triggerpercentage') : (int) $box->params->get('scroll_pixel'),
            'firing_frequency'     => (int) $box->params->get('firing_frequency', 1),
            'reverse_scroll_close' => (bool) $box->params->get('autohide'),
            'threshold'            => (float) $box->params->get('threshold', 0) / 100,
            'close_out_viewport'   => (bool) $box->params->get('close_out_viewport', false),
            'exit_timer'           => (int) $box->params->get('exittimer'),
            'idle_time'            => (int) $box->params->get('idle_time') * 1000,
            'animation_open'       => $box->params->get('animationin'),
            'animation_close'      => $box->params->get('animationout'),
            'animation_duration'   => (int) $box->params->get('duration'),
            'prevent_default'      => (bool) $box->params->get('preventdefault', true),
            'backdrop'             => (bool) $box->params->get('overlay'),
            'backdrop_color'       => $box->params->get('overlay_color'),
            'backdrop_click'       => (bool) $box->params->get('overlayclick'),
            'disable_page_scroll'  => (bool) ($box->params->get('preventpagescroll', '2') == '2' ? $cParam->get('preventpagescroll', false) : $box->params->get('preventpagescroll')),
            'test_mode'            => (bool) $box->testmode,
            'debug'                => (bool) $cParam->get('debug', false),
            'ga_tracking'          => (bool) $cParam->get('gaTrack', 0),
            'ga_tracking_id'       => $cParam->get('gaID', 0),
            'ga_tracking_label'    => $cParam->get('gaCategory'),
            'auto_focus'           => (bool) $box->params->get('autofocus', false),
        ];

        $box->styles_container = Helper::arrayToCSSS([
            'z-index' => $box->params->get('zindex', 99999) != 99999 ? $box->params->get('zindex') : null
        ]);
    }

    /**
     * Get a box object from the database
     *
     * @param  integer $id  The box's primary key
     *
     * @return object
     */
    public static function get($id)
    {
        $hash = md5('box_' . $id);

        if (Cache::has($hash))
        {
            return Cache::read($hash);
        }

        // Get a db connection.
        $db = \JFactory::getDbo();
        $query = $db->getQuery(true);
         
        $query->select('*')
            ->from($db->quoteName('#__rstbox'))
            ->where($db->quoteName('id') . ' = '. (int) $id);
         
        $db->setQuery($query);

        if (!$box = $db->loadObject())
        {
            return;
        }

        $box->params = new Registry($box->params);

        return Cache::set($hash, $box);
    }

    public static function isMirrored($id)
    {
        $boxes = Boxes::getAll();

        foreach ($boxes as $key => $box)
        {
            if (!isset($box->params->mirror) || !isset($box->params->mirror_box))
            {
                continue;
            }

            if ($box->params->mirror && $box->params->mirror_box == $id)
            {
                return true;
            }
        }

        return false;
    }

    public static function pass($box)
    {
        if (!$box)
        {
            return;
        }

        // Prepare boxes that mirror other boxes assignments
        if ($box->params->get('mirror', false) && $mirror_box_id = $box->params->get('mirror_box'))
        {
            $box->params->merge(self::getAssignmentsForMirroring($mirror_box_id));
        }

        // Check first local assignments
        if (!self::passLocalAssignments($box))
        {
            return false;
        }

        // If testmode is enabled disable the User Groups assignment
        if ($box->testmode)
        {
            $box->params->set('assign_usergroups', false);
        }

        // Check framework based assignments
        return self::passGlobalAssignments($box);
    }

    private static function passGlobalAssignments($box)
    {
        $assignments = new \NRFramework\Assignments();
        return $assignments->passAll($box, $box->params->get('assignmentMatchingMethod', 'and'));
    }

    /**
     * Check if a box passes local assignments
     *
     * @param [type] $box
     *
     * @return void
     */
    private static function passLocalAssignments($box)
    {
        $localAssignments = new \EngageBox\Assignments($box);
        return $localAssignments->passAll();
    }

    private static function getAssignmentsForMirroring($box_id)
    {   
        // Load $box_id
        if (!$box = Box::get($box_id))
        {
            return;
        }

        // To prevent user frustration, we ignore the following assignments because they are not displayed in the Publishing Assignments.
        $params_to_ignore = [
            'assign_impressions',
            'assign_offline'
        ];

        $assignments = [];

        // Gather params to merge
        foreach ($box->params as $param_key => $param_value)
        {
            if (strpos($param_key, 'assign') === false || in_array($param_key, $params_to_ignore))
            {
                continue;
            }

            $assignments[$param_key] = $param_value;
        }

        return new Registry($assignments);
    }

    public static function logOpenEvent($box_id)
    {
        $box = self::get($box_id);

        // Do not track if statistics option is disabled
        $track_open_event = (bool) (is_null($box->params->get('stats', null)) ? Helper::getParams()->get('stats', 1) : $box->params->get('stats'));
        if (!$track_open_event)
        {
            return;
        }

        Log::track($box_id);
    }

    private static function prefixCSSClasses(&$classes, $prefix = 'eb-')
    {
        $classes = array_filter($classes);

        foreach ($classes as &$class)
        {
            $class = $prefix . $class;
        }
    }
}